﻿using System;
using Windows.Foundation;
using Windows.Graphics.Display;
using Windows.UI.ViewManagement;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Navigation;

namespace TestProject
{
    /// <summary>
    /// 메인 페이지
    /// </summary>
    public sealed partial class MainPage : Page
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainPage()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainPage()
        {
            InitializeComponent();

            #region 윈도우 크기를 설정한다.

            double width  = 800d;
            double height = 600d;

            double dpi = (double)DisplayInformation.GetForCurrentView().LogicalDpi;

            ApplicationView.PreferredLaunchWindowingMode = ApplicationViewWindowingMode.PreferredLaunchViewSize;

            Size windowSize = new Size(width * 96d / dpi, height * 96d / dpi);

            ApplicationView.PreferredLaunchViewSize = windowSize;

            Window.Current.Activate();

            ApplicationView.GetForCurrentView().TryResizeView(windowSize);

            #endregion
            #region 윈도우 제목을 설정한다.

            ApplicationView.GetForCurrentView().Title = "NavigationView 엘리먼트 : ItemInvoked 이벤트를 사용해 탐색 스택 추가하지 않기";

            #endregion

            this.navigationView.Header = "샘플 페이지 1";

            FrameNavigationOptions option = new FrameNavigationOptions();

            if(this.navigationView.PaneDisplayMode == Microsoft.UI.Xaml.Controls.NavigationViewPaneDisplayMode.Top)
            {
                option.IsNavigationStackEnabled = false;
            }

            this.frame.NavigateToType(typeof(SamplePage1), null, option);
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 네비게이션 뷰 항목 호출시 처리하기 - navigationView_ItemInvoked(sender, e)

        /// <summary>
        /// 네비게이션 뷰 항목 호출시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void navigationView_ItemInvoked(Microsoft.UI.Xaml.Controls.NavigationView sender, Microsoft.UI.Xaml.Controls.NavigationViewItemInvokedEventArgs e)
        {
            FrameNavigationOptions option = new FrameNavigationOptions();

            option.TransitionInfoOverride = e.RecommendedNavigationTransitionInfo;

            if(sender.PaneDisplayMode == Microsoft.UI.Xaml.Controls.NavigationViewPaneDisplayMode.Top)
            {
                option.IsNavigationStackEnabled = false;
            }

            Type pageType = null;

            Microsoft.UI.Xaml.Controls.NavigationViewItem item = e.InvokedItemContainer as Microsoft.UI.Xaml.Controls.NavigationViewItem;

            if(item.Name == "navigationViewItem1")
            {
                pageType = typeof(SamplePage1);

                sender.Header = "샘플 페이지 1";

            }
            else if(item.Name == "navigationViewItem2")
            {
                pageType = typeof(SamplePage2);

                sender.Header = "샘플 페이지 2";
            }
            else if(item.Name == "navigationViewItem3")
            {
                pageType = typeof(SamplePage3);

                sender.Header = "샘플 페이지 3";
            }
            else if(item.Name == "navigationViewItem4")
            {
                pageType = typeof(SamplePage4);

                sender.Header = "샘플 페이지 4";
            }

            if(pageType != null)
            {
                this.frame.NavigateToType(pageType, null, option);
            }
        }

        #endregion
    }
}